This project is mainly used for machine learning in resting-state fMRI field. Our goal is to develop a graphical interface so that researchers who are not familiar with programming can easily apply machine learning to their fields.

**At present, the project is in the development stage. We hope you can join us!**

Email: lichao19870617@gmail.com
weChart: QQ312214129.